==> stealth_id-0.0.2.tar.gz: ios/Classes/CarespaceFaceAuth.swift <==
//
//  CarespaceFaceAuth.swift
//  risecx_stealthId
//
//  Created by Crístofer Domingues on 14/04/21.
//

import Foundation


public class CarespaceFaceAuth {
    
    var service : CarespaceService
    
    //Webservice call
    internal var baseURL = ""
    internal let defaultRequestDictionary = [
    
    "client_id" : "SIClient",
        
    "client_secret": "0f95d876-fa17-4b15-88d0-0b38acbd1b76",

    "response_type" : "token id_token",

    "realm" : "si_realm",

    "redirect_uri" : "http://test",

    "scope" : "openid",

    "state" : "openid",

    "nonce" : "13243",
        
    "customerCode": "providence"
 ]
    
    internal var defaultRequestHeader : [String : String]
    
    init(viewController: FlutterViewController, baseURL:String ,apiHeader : [String : String]){
        self.service = CarespaceService(viewController:viewController, baseURL: baseURL, apiHeader: apiHeader)
        self.baseURL = baseURL.appending(":30643/sisaas/oidc/2.1.4/")
        self.defaultRequestHeader = apiHeader
        self.defaultRequestHeader.updateValue("application/x-www-form-urlencoded", forKey: "Content-Type")
    }
    
    public func authenticateEnrolledUser(_ userID : String, result: @escaping FlutterResult){
        print("authenticateEnrolledUser -- Enter")
        self.checkUsername(userID: userID, completionHandler: { (checkUsernameResult) in
            guard let sessionId = checkUsernameResult["sessionId"] as? String,  let transactionId = checkUsernameResult["transactionId"] as? String else {
                result(FlutterError.init(code: "REQUEST_FAIL", message: checkUsernameResult["message"] as? String, details: nil))
                return
            }
            self.service.takePictureFromAwareLiveness(userId: userID, transactionId: transactionId) { (takePictureResult) in
                guard let  livenessInfo  = takePictureResult["livenessInfo"] as? [String : Any],
                      let video = livenessInfo["video"] as? [String:Any],
                      let autoCaptureResult = video["autocapture_result"] as? [String:Any],
                      let capturedFrame = autoCaptureResult["captured_frame"] as? String else {
                          result(FlutterError.init(code: "AWARE_LIVENESS_FAIL", message: takePictureResult["message"] as? String, details: nil))
                          return
                }
                self.onDetectionResultSuccess(userID, capturedFrame, sessionId, result)
                //result(takePictureResult)
            }
        })
       
      
        print("authenticateEnrolledUser -- Exit")
    }
    
    private func onDetectionResultSuccess(_ userID:String, _ capturedImage:String, _ sessionId : String, _ result: @escaping FlutterResult){
        print("onDetectionResultSuccess -- Enter")
      
        self.verifyUserFace(base64Image:capturedImage, userID: userID, sessionID: sessionId, completionHandler: { (verifyUserFaceResult) in
            guard let _ = verifyUserFaceResult["token"] as? String else{
                result(FlutterError.init(code: "REQUEST_FAIL", message: verifyUserFaceResult["message"] as? String, details: nil))
                return
            }
            result(verifyUserFaceResult);
        })
        print("onDetectionResultSuccess -- Exit")
    }
    
    
  
    private func checkUsername(userID:String, completionHandler: @escaping (Dictionary<String, Any>) -> Void){
        print("checkUsername -- Enter "+userID)
        var checkUsernameReqDic = defaultRequestDictionary;
        checkUsernameReqDic.updateValue(userID, forKey: "username");
        checkUsernameReqDic.updateValue("username", forKey: "grant_type")
        checkUsernameReqDic.updateValue("code", forKey: "response_type")
        
      
        
        self.service.webserviceCaller(baseURL+"token",requestHeader: defaultRequestHeader, httpBodyData: nil,requestDictonary:checkUsernameReqDic) {(response:Dictionary<String, Any>) in
            guard let sessionId = response["sessionId"] as? String,  let transactionId = response["transactionId"] as? String else {
                let errorMessage: String = response["message"] as? String ?? "Check Username request has failed"
                completionHandler(["success":false,"message": errorMessage, "expectedResult": ""])
                print("checkUsername -- Fail "+errorMessage)
                return
            }
            completionHandler(["success":true, "sessionId": sessionId, "transactionId" : transactionId])
           print("checkUsername -- Exit")
        }
    }
    
    private func verifyUserFace(base64Image:String!,userID:String, sessionID:String,completionHandler: @escaping (Dictionary<String, Any>) -> Void) {
        print("verifyUserFace -- Enter ")
        var verifyUserReqDic = defaultRequestDictionary;
        verifyUserReqDic.updateValue(userID, forKey: "username");
        verifyUserReqDic.updateValue(sessionID, forKey: "sessionId");
        verifyUserReqDic.updateValue(base64Image, forKey: "bioData");
        verifyUserReqDic.updateValue("token id_token", forKey: "response_type")
        verifyUserReqDic.updateValue("face", forKey: "grant_type")
        self.service.webserviceCaller(baseURL+"token", requestHeader: self.defaultRequestHeader, httpBodyData: nil, requestDictonary:verifyUserReqDic) { (userFaceVerificationResult) in
            let errorMessage = userFaceVerificationResult["message"] as? String ?? "User's face verification request has failed"
            guard let _ = userFaceVerificationResult["access_token"] else {
            completionHandler(["success":false, "message":errorMessage , "expectedResult": ""])
            print("verifyUserFace -- Fail "+errorMessage)
            return
            }
           
            completionHandler(["success": true, "token":userFaceVerificationResult["access_token"] as! String])
            
            print("verifyUserFace -- Exit ")
        }
    }
     
    
}

==> stealth_id-0.0.6.tar.gz: ios/Classes/CarespaceFaceAuth.swift <==
//
//  CarespaceFaceAuth.swift
//  risecx_stealthId
//
//  Created by Crístofer Domingues on 14/04/21.
//

import Foundation


public class CarespaceFaceAuth {
    
    var service : CarespaceService
    
    //Webservice call
    internal var baseURL = ""
    internal let defaultRequestDictionary = [
    
    "client_id" : "SIClient",
        
    "client_secret": "0f95d876-fa17-4b15-88d0-0b38acbd1b76",

    "response_type" : "token id_token",

    "realm" : "si_realm",

    "redirect_uri" : "http://test",

    "scope" : "openid",

    "state" : "openid",

    "nonce" : "13243",
        
    "customerCode": "carespacedoc"
 ]
    
    internal var defaultRequestHeader : [String : String]
    
    init(viewController: FlutterViewController, baseURL:String ,apiHeader : [String : String]){
        self.service = CarespaceService(viewController:viewController, baseURL: baseURL, apiHeader: apiHeader)
        self.baseURL = baseURL.appending(":30643/sisaas/oidc/2.2.0/")
        self.defaultRequestHeader = apiHeader
        self.defaultRequestHeader.updateValue("application/x-www-form-urlencoded", forKey: "Content-Type")
    }
    
    public func authenticateEnrolledUser(_ userID : String, result: @escaping FlutterResult){
        print("authenticateEnrolledUser -- Enter")
        self.checkUsername(userID: userID, completionHandler: { (checkUsernameResult) in
            guard let sessionId = checkUsernameResult["sessionId"] as? String,  let transactionId = checkUsernameResult["transactionId"] as? String else {
                result(FlutterError.init(code: "REQUEST_FAIL", message: checkUsernameResult["message"] as? String, details: nil))
                return
            }
            self.service.takePictureFromAwareLiveness(userId: userID, transactionId: transactionId) { (takePictureResult) in
                guard let  livenessInfo  = takePictureResult["livenessInfo"] as? [String : Any],
                      let video = livenessInfo["video"] as? [String:Any],
                      let autoCaptureResult = video["autocapture_result"] as? [String:Any],
                      let capturedFrame = autoCaptureResult["captured_frame"] as? String else {
                          result(FlutterError.init(code: "AWARE_LIVENESS_FAIL", message: takePictureResult["message"] as? String, details: nil))
                          return
                }
                self.onDetectionResultSuccess(userID, capturedFrame, sessionId, result)
                //result(takePictureResult)
            }
        })
       
      
        print("authenticateEnrolledUser -- Exit")
    }
    
    private func onDetectionResultSuccess(_ userID:String, _ capturedImage:String, _ sessionId : String, _ result: @escaping FlutterResult){
        print("onDetectionResultSuccess -- Enter")
      
        self.verifyUserFace(base64Image:capturedImage, userID: userID, sessionID: sessionId, completionHandler: { (verifyUserFaceResult) in
            guard let _ = verifyUserFaceResult["token"] as? String else{
                result(FlutterError.init(code: "REQUEST_FAIL", message: verifyUserFaceResult["message"] as? String, details: nil))
                return
            }
            result(verifyUserFaceResult);
        })
        print("onDetectionResultSuccess -- Exit")
    }
    
    
  
    private func checkUsername(userID:String, completionHandler: @escaping (Dictionary<String, Any>) -> Void){
        print("checkUsername -- Enter "+userID)
        var checkUsernameReqDic = defaultRequestDictionary;
        checkUsernameReqDic.updateValue(userID, forKey: "username");
        checkUsernameReqDic.updateValue("username", forKey: "grant_type")
        checkUsernameReqDic.updateValue("code", forKey: "response_type")
        
      
        
        self.service.webserviceCaller(baseURL+"token",requestHeader: defaultRequestHeader, httpBodyData: nil,requestDictonary:checkUsernameReqDic) {(response:Dictionary<String, Any>) in
            guard let sessionId = response["sessionId"] as? String,  let transactionId = response["transactionId"] as? String else {
                let errorMessage: String = response["message"] as? String ?? "Check Username request has failed"
                completionHandler(["success":false,"message": errorMessage, "expectedResult": ""])
                print("checkUsername -- Fail "+errorMessage)
                return
            }
            completionHandler(["success":true, "sessionId": sessionId, "transactionId" : transactionId])
           print("checkUsername -- Exit")
        }
    }
    
    private func verifyUserFace(base64Image:String!,userID:String, sessionID:String,completionHandler: @escaping (Dictionary<String, Any>) -> Void) {
        print("verifyUserFace -- Enter ")
        var verifyUserReqDic = defaultRequestDictionary;
        verifyUserReqDic.updateValue(userID, forKey: "username");
        verifyUserReqDic.updateValue(sessionID, forKey: "sessionId");
        verifyUserReqDic.updateValue(base64Image, forKey: "bioData");
        verifyUserReqDic.updateValue("token id_token", forKey: "response_type")
        verifyUserReqDic.updateValue("face", forKey: "grant_type")
        self.service.webserviceCaller(baseURL+"token", requestHeader: self.defaultRequestHeader, httpBodyData: nil, requestDictonary:verifyUserReqDic) { (userFaceVerificationResult) in
            let errorMessage = userFaceVerificationResult["message"] as? String ?? "User's face verification request has failed"
            guard let _ = userFaceVerificationResult["access_token"] else {
            completionHandler(["success":false, "message":errorMessage , "expectedResult": ""])
            print("verifyUserFace -- Fail "+errorMessage)
            return
            }
           
            completionHandler(["success": true, "token":userFaceVerificationResult["access_token"] as! String])
            
            print("verifyUserFace -- Exit ")
        }
    }
     
    
}
